from .data_source import DataSource
from .layout import AnalysisLayout
from .visual_analysis import VisualAnalysis

# Import Widgets so that they get registered
import pandas_visual_analysis.widgets


import plotly.io as pio

pio.templates.default = "plotly_white"
